@@ -1,7 +1,7 @@
 import pickle
 import math
 import os
-
+from pathlib import Path
 from .normalizer import Normalizer
 from .tokenizer import Tokenizer
 from .data_helper import DataHelper
@@ -15,10 +15,14 @@ class SpellCheck:
 
         self.dir_path = os.path.dirname(os.path.realpath(__file__)) + "/"
 
-        # self.bigram_lm = self.data_helper.load_var(self.dir_path + "resource/spell/mybigram_lm.pckl")
-        # self.onegram_lm = self.data_helper.load_var(self.dir_path + "resource/spell/onegram.pckl")
-        self.bigram_lm = ""
-        self.onegram_lm = ""
+
+        my_file = Path(self.dir_path + "resource/spell")
+        if not my_file.is_file():
+            os.system("cd {}/resource/".format(self.dir_path ))
+            os.system("!gdown --id 1GzsIhyArv3SgJmNKzU38_QEuY6lMbq_j")
+        self.bigram_lm = self.data_helper.load_var(self.dir_path + "resource/spell/created_bigram.pckl")
+        self.onegram_lm = self.data_helper.load_var(self.dir_path + "resource/spell/created_onegram.pckl")
+
 
         self.ingroup_chars = [{'ا', 'آ', 'ع'},
                               {'ت', 'ط'},
